@@ -1,9 +1,13 @@
 use crate::process::ProcessInfo;
 #[cfg(target_os = "windows")]
 use crate::util::format_sid;
+#[cfg(not(target_os = "windows"))]
+use crate::util::USERS_CACHE;
 use crate::{column_default, Column};
 use std::cmp;
 use std::collections::HashMap;
+#[cfg(not(target_os = "windows"))]
+use uzers::Users;
 
 pub struct User {
     header: String,
@@ -33,7 +37,7 @@ impl User {
 #[cfg(any(target_os = "linux", target_os = "android"))]
 impl Column for User {
     fn add(&mut self, proc: &ProcessInfo) {
-        let user = users::get_user_by_uid(proc.curr_proc.owner());
+        let user = USERS_CACHE.with(|x| x.borrow_mut().get_user_by_uid(proc.curr_proc.owner()));
         let fmt_content = if let Some(user) = user {
             format!("{}", user.name().to_string_lossy())
         } else {
@@ -53,11 +57,12 @@ impl Column for User {
 impl Column for User {
     fn add(&mut self, proc: &ProcessInfo) {
         let uid = proc.curr_task.pbsd.pbi_uid;
-        let fmt_content = if let Some(user) = users::get_user_by_uid(uid) {
-            format!("{}", user.name().to_string_lossy())
-        } else {
-            format!("{}", uid)
-        };
+        let fmt_content =
+            if let Some(user) = USERS_CACHE.with(|x| x.borrow_mut().get_user_by_uid(uid)) {
+                format!("{}", user.name().to_string_lossy())
+            } else {
+                format!("{}", uid)
+            };
         let raw_content = fmt_content.clone();
 
         self.fmt_contents.insert(proc.pid, fmt_content);
@@ -84,3 +89,23 @@ impl Column for User {
 
     column_default!(String);
 }
+
+#[cfg_attr(tarpaulin, skip)]
+#[cfg(target_os = "freebsd")]
+impl Column for User {
+    fn add(&mut self, proc: &ProcessInfo) {
+        let uid = proc.curr_proc.info.uid;
+        let fmt_content =
+            if let Some(user) = USERS_CACHE.with(|x| x.borrow_mut().get_user_by_uid(uid)) {
+                format!("{}", user.name().to_string_lossy())
+            } else {
+                format!("{}", uid)
+            };
+        let raw_content = fmt_content.clone();
+
+        self.fmt_contents.insert(proc.pid, fmt_content);
+        self.raw_contents.insert(proc.pid, raw_content);
+    }
+
+    column_default!(String);
+}
